local dir `c(pwd)'
capture mkdir correlations

/* program to calculate part Spearman */
capture program drop pspear
program pspear, rclass
quietly {
version 14
syntax varlist(min=3 max=3) [if] [in] [aw fw]
args var1 var2 control
marksample touse
tempvar var1_r var2_r control_r var1_resid var2_resid
egen `var1_r'=rank(`var1') if `touse'
egen `var2_r'=rank(`var2') if `touse'
egen `control_r'=rank(`control') if `touse'

/* Reg `var2_r' on `control_r' and obtain residuals */
reg `var2_r' `control_r'
predict `var2_resid', resid 

*Part (Semi-partial) correlation   
corr `var1_r' `var2_resid'
return scalar pspear=r(rho)
return scalar N=r(N)
}
end


capture program drop get_data
program get_data
args variable1 variable2 controlvariable folder Group variation
qui {	           
	if "`Group'"=="Indo-European"|"`Group'"=="Altaic"|"`Group'"=="Niger-Congo"|"`Group'"=="Afro-Asiatic"|"`Group'"=="Austronesian"|"`Group'"=="Sino-Tibetan" {
	local Keyvariable Family
	}
	else {
	local Keyvariable Area
	}
local list `"0 6"'
	if !("`variable1'"=="MC"|"`variable2'"=="MC") {
		*Num Chap only releveant for test with MC
		local list 0
	}
	if "`Group'"!="All" {
		*Full list only for "All"
		local list 0
	}

/* create empty dataset to store the results */		
clear
set obs 1
gen NumChap=.
gen spearman=.
gen s_perm=.
gen N_s=.
gen pspearman=.
gen ps_perm=.
gen N_ps=.
save `"`folder'\correlations\spearman_`variable1'_`variable2'_`controlvariable'_`Group'`variation'"', replace
	noisily di "`variable1' `variable2' `controlvariable' | `Group'"
foreach i of local list  {
	local NumChapRelevant
	local s_avail
	local ps_avail
	use data, clear
	
	/* For the L1plusL2 version: add estimated L2 number to population estimate */
	if "`variation'"=="L1plusL2" {
		drop if L2prop==.
		replace Pop=Pop/(1-L2prop) if L2prop!=1
	}
	
	/* For the vehicularity0 version: drop all non vehicular languages with L2prop>0 */
	if "`variation'"=="vehicularity0" {
		drop if vehicularity==0 & L2prop>0
	}
	
	/* For the vehicularity1 version: keep only cases where vehicularity ==1  */
	if "`variation'"=="vehicularity1" {
		keep if vehicularity==1
	}
	
	if "`Group'"!="All" {
		keep if `Keyvariable'=="`Group'" 
	}
	drop if `variable1'==.|`variable2'==.
	*NumChap only relevant for Morphological complexity
	if ("`variable1'"=="MC"|"`variable2'"=="MC") {
		keep if NumChap>=`i' 
		local NumChapRelevant yes
	}	
	
	/* only if enough available cases (N >=5) */
	if _N>=5 {
		local s_avail yes
	
	/* Spearman correlation */	
	spearman `variable1' `variable2'
	local spearman=r(rho)
	local N_s=r(N)
	set seed 156974
	if r(rho)>=0 {
			/*estimate of Pr(T* >= T) */
			local oneside right
		}
		else {
			/*estimate of Pr(T* <= T) */
			local oneside left
		}
	
	/* Permutation test */
	permute `variable1' rho=r(rho),reps(100000) nodots nowarn `oneside':  spearman `variable1' `variable2' 
	tempname temp1
	mat `temp1'=r(p)
	local s_perm=`temp1'[1,1]
	}
	if "`controlvariable'"!="none" {
	drop if `variable1'==.|`variable2'==.|`controlvariable'==.
	/* only if enough available cases (N >=5) */
	if _N>=5 {
		local ps_avail yes
	
	/* Part Spearman correlation */	
	pspear `variable1' `variable2' `controlvariable'
	local pspearman=r(pspear)
	local N_ps=r(N)
	if r(pspear)>=0 {
			/*estimate of Pr(T* >= T) */
			local oneside right
		}
		else {
			/*estimate of Pr(T* <= T) */
			local oneside left
		}
	
	/* Permuation test */	
	permute `variable1'  rho=r(pspear), reps(100000) nodots nowarn `oneside':  pspear `variable1' `variable2' `controlvariable' 
	tempname temp2
	mat `temp2'=r(p)
	local ps_perm=`temp2'[1,1]
	}
	}
	/* Store the results */
	use `"`folder'\correlations\spearman_`variable1'_`variable2'_`controlvariable'_`Group'`variation'"', clear
	local new=_N+1
	set obs `new'
	if "`NumChapRelevant'"=="yes" {
	replace NumChap=`i' in `new'
	}
	if "`s_avail'"=="yes" {
	replace N_s=`N_s' in `new'
	replace spearman=`spearman' in `new'
	replace s_perm=`s_perm' in `new'
	}	
	if "`ps_avail'"=="yes" {
	replace pspearman=`pspearman' in `new'
	replace ps_perm=`ps_perm' in `new'	
	replace N_ps=`N_ps' in `new'	
	}
	egen miss=rowmiss(_all)
	drop if miss==7
	drop miss
	save `"`folder'\correlations\spearman_`variable1'_`variable2'_`controlvariable'_`Group'`variation'"', replace
}
}
end
    get_data Population L2prop none `dir' `1' `2'  
		get_data MC H none `dir' `1' `2'
		get_data MC L2prop Population `dir' `1' `2'
		get_data MC Population L2prop `dir' `1' `2'
		get_data H L2prop Population `dir' `1' `2'
		get_data H Population L2prop `dir' `1' `2'

* generate finished file */
clear
set obs 1
gen v=1
save finished_`1', replace
clear         
exit, STATA 
