local dir `c(pwd)'

/* program to calculate part Spearman */
capture program drop pspear
program pspear, rclass
quietly {
version 14
syntax varlist(min=3 max=3) [if] [in] [aw fw]
args var1 var2 control
marksample touse
tempvar var1_r var2_r control_r var1_resid var2_resid
egen `var1_r'=rank(`var1') if `touse'
egen `var2_r'=rank(`var2') if `touse'
egen `control_r'=rank(`control') if `touse'

/* Reg `var2_r' on `control_r' and obtain residuals */
reg `var2_r' `control_r'
predict `var2_resid', resid 

*Part (Semi-partial) correlation   
corr `var1_r' `var2_resid'
return scalar pspear=r(rho)
return scalar N=r(N)
}
end

capture program drop get_data
program get_data
args variable1 variable2 controlvariable folder Type reps save
qui {
	
local list `"0 6"'
	if !("`variable1'"=="MC"|"`variable2'"=="MC") {
		*For entropy rates Num Chap only releveant for test with MC
		local list 0
	}

foreach l of local list  {	
	clear
	set obs `reps'
	gen NumChap=`l'
	gen spearman=.
	gen N_s=.
	gen pspearman=.
	gen N_ps=.
	save `"`folder'\correlations\spearman_`variable1'_`variable2'_`controlvariable'_`Type'_`l'"', replace

	/* monte carlo sim */
	*Prepare data sets
	
		use if `Type'!="" using data, clear	
		drop if `variable1'==.|`variable2'==.
		*NumChap only relevant for Morphological complexity
		if ("`variable1'"=="MC"|"`variable2'"=="MC") {
			keep if NumChap>=`l' 
		}	
		
		bysort `Type': gen howmany=_N
		*At least five available cases per `Type', otherwise put into "other" group
		replace `Type'="other" if howmany<5
		save T1_`save', replace
		
		if "`controlvariable'"!="none" {
		use if `Type'!="" using data, clear	
		drop if `variable1'==.|`variable2'==.|`controlvariable'==.
		*NumChap only relevant for Morphological complexity
		if ("`variable1'"=="MC"|"`variable2'"=="MC") {
			keep if NumChap>=`l' 
		}	
		
		bysort `Type': gen howmany=_N
		*At least five available cases per `Type', otherwise put into "other" group
		replace `Type'="other" if howmany<5
		save T2_`save', replace
	}
	forvalues i=1/`reps' {
		local show=`reps'/10
		if mod(`i',`show')==0 {
		noisily di "`variable1' `variable2' `controlvariable' | `Type' | `i' | NumChap=`l'"
		}
		use T1_`save', clear
		
		/* Monte carlo simulation: sample 1 case per `Type' per repition */
		sample 1, by(`Type') count
		
		/* Spearman correlation */
		spearman `variable1' `variable2'
		local spearman_`i'=r(rho)
		local N_s_`i'=r(N)
		
		if "`controlvariable'"!="none" {
		use T2_`save', clear
		/* Part Spearman correlation */		
		sample 1, by(`Type') count
		pspear `variable1' `variable2' `controlvariable'
		local pspearman_`i'=r(pspear)
		local N_ps_`i'=r(N)
	}
	}
	/* Store results */
	use `"`folder'\correlations\spearman_`variable1'_`variable2'_`controlvariable'_`Type'_`l'"', clear
	forvalues i=1/`reps' {
	replace N_s=`N_s_`i'' in `i'
	replace spearman=`spearman_`i'' in `i'
		if "`controlvariable'"!="none" {
	replace pspearman=`pspearman_`i'' in `i'	
	replace N_ps=`N_ps_`i'' in `i'	
}
	}
	save `"`folder'\correlations\spearman_`variable1'_`variable2'_`controlvariable'_`Type'_`l'"', replace
}
if !("`variable1'"=="MC"|"`variable2'"=="MC") {
		use `"`folder'\correlations\spearman_`variable1'_`variable2'_`controlvariable'_`Type'_0"', clear
		save `"`folder'\correlations\spearman_`variable1'_`variable2'_`controlvariable'_`Type'"', replace
	}
	else {
		use `"`folder'\correlations\spearman_`variable1'_`variable2'_`controlvariable'_`Type'_0"', clear
		append using `"`folder'\correlations\spearman_`variable1'_`variable2'_`controlvariable'_`Type'_6"'
		save `"`folder'\correlations\spearman_`variable1'_`variable2'_`controlvariable'_`Type'"', replace
		}
capture erase `"`folder'\correlations\spearman_`variable1'_`variable2'_`controlvariable'_`Type'_0.dta"' 
capture erase `"`folder'\correlations\spearman_`variable1'_`variable2'_`controlvariable'_`Type'_6.dta"'
capture erase T1_`save'.dta
capture erase T2_`save'.dta
}
end

		get_data `1' `2' `3' `dir' `4' 100000 `5'
  
* generate finished file */
clear
set obs 1
gen v=1
save finished_`5', replace
clear         
exit, STATA  
