local dir `c(pwd)'
*Generate a dataset with Information from:
*Basic ISO Information and Family information taken from Mayer & Cysouw's PBC
*Information on areas taken from Bickel and Nichol’s AUTOTYP database (www.spw.uzh.ch/autotyp/)
*Morphological complexity taken from Bentz, C., Ruzsics, T., Koplenig, A. and Samardžic, T. (2016). A comparison between morphological complexity measures: typological data vs. language corpora. (From CB:WALS_agr_ScalingTo1)
*Entropy rates taken from Koplenig, Alexander; Meyer, Peter; Wolfer, Sascha; Müller-Spitzer, Carolin, 2017, "Replication Data for: The statistical trade-off between word order and word structure – large-scale evidence for the principle of least effort" (http://dx.doi.org/10.7910/DVN/8KH0GB)
*L2prop is taken as from the Ethnologue Global Dataset (20th edition), the terms of use (Personal Research License) allow this, as the raw data cannot be reconstructed from this aggregation of variables [(All_Users-L1_Users)/All_Users]  ("You may freely publish and distribute [...] tables presenting results that aggregate over the data.
*Additional L2prop are taken from Bentz et al. (2015) Adaptive Communication: Languages with More Non-Native Speakers Tend to Have Fewer Word Forms. 
*Additional population estimates downloaded from Amano et al. (2014) - Global distribution and drivers of language extinction risk (http://rspb.royalsocietypublishing.org/content/281/1793/20141574.figures-only)
*Unigram entropies are taken from Bentz et al. (2017) - The entropy of words - learnability and expressivity across more than 1000 languages. Entropy, 19(6), 2

*Read in Bentz et al (2018): morphological complexity
import delimited WALS_agr_ScalingTo1.csv, case(preserve) encoding(UTF-8) clear 
rename iso ISO
rename C_W MC
save data, replace

*Read in Koplenig et al (2017): entropy rates
import delimited final_data_entropy_bible.csv, encoding(UTF-8) clear case(preserve) 
*Book : Mark
keep if book==41
bysort ISO: egen H=mean(H_original)
sample 1, by(ISO) count
merge 1:1 ISO using data, nogenerate
split family, p(",")
gen Fam=family1
drop translation words chars book* H_* D_* longi lati fam*
save data, replace

**Read in Mayer&Cysouw: language & families basic information
import delimited ISO639-3.tsv, encoding(UTF-8) clear 
ren v1 ISO
split v5, p(",")
gen Family=v51
gen Language=v2
keep ISO Family Language
merge 1:1 ISO using data, nogenerate
replace Family=Fam if Family==""
replace Language=language if Language==""
drop language Fam
save data, replace

**Read in Bickel and Nichols’s AUTOTYP database: areal information

import delimited autotyp.csv, bindquote(strict) stripquote(yes) case(preserve) encoding(UTF-8) clear 
rename ISO ISO
keep ISO stock area
replace ISO=ustrleft(ISO,3)
drop if ISO==""
sample 1, by(ISO) c
merge 1:1 ISO using data
rename area Area 
drop _merge
keep ISO Language Family Area H MC NumChap
save data, replace

*Read in Amano et al. (2014) - population estimates and range sizes 
import excel rspb20141574supp2.xls, sheet("Figure1abd") firstrow clear
ren Pop TEMP
gen double Population=TEMP
drop TEMP
rename LanguageISO ISO
replace ISO=ustrlower(ISO)
merge 1:1 ISO using data, nogenerate
save data, replace

*Read in aggregated Ethnologue data: Vehicularity
import delimited "F:\stat_learn\Ethnologue 20 Global Dataset\Table_of_Languages.tab", case(preserve) encoding(UTF-8) clear 
rename ISO ISO
gen vehicularity=1 if EGIDS=="0"|EGIDS=="1"|EGIDS=="2"|EGIDS=="3"
replace vehicularity=0 if EGIDS=="4"|EGIDS=="5"|EGIDS=="6a"|EGIDS=="6b"|EGIDS=="7"|EGIDS=="8a"|EGIDS=="8b"|EGIDS=="9"|EGIDS=="x10"
keep ISO vehicularity All
merge 1:1 ISO using data, nogenerate
save data, replace

*Read in aggregated Ethnologue data: L2prop
import delimited "F:\stat_learn\Ethnologue 20 Global Dataset\Table_of_LICs.tab", case(preserve) encoding(UTF-8) clear 
gen vehicularity=1 if EGIDS=="0"|EGIDS=="1"|EGIDS=="2"|EGIDS=="3"
replace vehicularity=0 if EGIDS=="4"|EGIDS=="5"|EGIDS=="6a"|EGIDS=="6b"|EGIDS=="7"|EGIDS=="8a"|EGIDS=="8b"|EGIDS=="9"|EGIDS=="x10"
sort ISO


by ISO: egen howmanyL2miss=count(L2)
by ISO: egen double L2total=total(L2)
by ISO: egen double L1total=total(L1)

by ISO: egen max=max(vehicularity)
replace vehicularity=max
drop max

sample 1, by(ISO) c
keep vehicularity ISO L* Family EGIDS howmany
drop L1_ L2_
rename L2 L2
rename L1 L1
rename ISO ISO
save TEMP, replace

*Read in Bentz et al. (2015): additional L2prop Information
import delimited journal.pone.0128254.s007.CSV, case(preserve) encoding(UTF-8)  clear

rename iso ISO

sample 1, by(ISO) c



merge 1:1 ISO using TEMP
capture erase TEMP.dta
replace Family=Stock if Family==""
replace Language_Name=Language if Language_Name==""
replace L1=L1_speakers if L1==.
replace L2=L2_speakers if L2==.
gen double All=L1+L2
gen L2prop=L2/All
drop _merge
keep ISO L2prop L2 L1 howmany
merge 1:1 ISO using data, nogenerate


drop if vehicularity==.|Pop==.
drop if H==.&MC==.
*replace L2prop = missing for vehicular languages where no L2 estimates are available
replace L2prop=. if howmany==0 & vehicularity==1

order _all, alpha
compress

order ISO Language Family Area 

*Replace spaces in Area/Family variable
replace Area=subinstr(Area," ","-",.)
replace Family=subinstr(Family," ","-",.)


drop L1 L2 All how 



*Get additional language/family info

replace Language="Adzera" if ISO=="adz"
replace Language="Aari" if ISO=="aiw"
replace Language="Chittagonian" if ISO=="ctg"
replace Language="Gbaya-Mbodomo" if ISO=="gmm"
replace Language="Gbaya, Southwest" if ISO=="gso"
replace Language="Hmong Njua" if ISO=="hnj"
replace Language="Saamia" if ISO=="lsm"
replace Language="Laomian" if ISO=="lwm"
replace Language="Occitan" if ISO=="oci"
replace Language="Mundari" if ISO=="unr"
replace Language="Zhuang, Guibei" if ISO=="zgb"

replace Family="Austronesian" if ISO=="adz"
replace Family="Afro-Asiatic" if ISO=="aiw"
replace Family="Indo-European" if ISO=="ctg"
replace Family="Niger-Congo" if ISO=="gmm"
replace Family="Niger-Congo" if ISO=="gso"
replace Family="Hmong-Mien" if ISO=="hnj"
replace Family="Niger-Congo" if ISO=="lsm"
replace Family="Sino-Tibetan" if ISO=="lwm"
replace Family="Indo-European" if ISO=="oci"
replace Family="Austro-Asiatic" if ISO=="unr"
replace Family="Tai-Kadai" if ISO=="zgb"
save data, replace


*Bentz et al unigram entropies
copy "http://www.christianbentz.de/Data%20and%20Resources/BlockH_EPC_PBC_UDHR_50K.csv" H_unigram.csv, replace
import delimited H_unigram.csv, case(preserve) encoding(UTF-8) clear 

ren iso ISO
*Only Bible corpus data
keep if corpus=="PBC"
collapse H_ML, by(ISO)
rename H_ML H_unigram 
merge 1:1 ISO using data, nogenerate 

drop if vehicularity==.|Pop==.
sort ISO
order _all, alpha
order ISO Language Family Area

*Replace L2prop=0 for languages with vehicularity==0 & L2prop==. (N = 19)
replace L2prop=0 if vehicularity==0 & L2prop==.
save data, replace

exit