*Create empty dataset to store the data

clear
set obs 1
gen depvar=""
gen Fixed_effects=""
gen Random_intercepts=""
gen Random_slopes=""
gen NF=.
gen N=.
gen b_logPop=.
gen p_logPop=.
gen b_vehicularity=.
gen p_vehicularity=.
gen b_interaction=.
gen p_interaction=.
save parametric, replace

foreach n in 1 6 0 {
	if `n'==0 {
	local Keyvariable H
	local title "Entropy rate"
	}
	else {
	local Keyvariable MC
	local title "Morphological complexity"
	}
	

*1. Mixed Regression with Feffects only, no interaction
use if Num>=`n' & `Keyvariable'!=. using data, clear
gen logPop=log(Pop)

mixed `Keyvariable' logPop vehicularity

mat D=r(table)

local N=e(N)
local b_logPop=D[1,1]
local p_logPop=D[4,1]
local b_vehicularity=D[1,2]
local p_vehicularity=D[4,2]

use parametric, clear
local new=_N+1
set obs `new'
replace depvar="`title'" in  `new'
replace Fixed_effects="log Population, vehicularity" in `new'
replace Random_intercepts="" in `new'
replace Random_slopes="" in `new'
replace N=`N' in `new'
replace b_logPop=`b_logPop'                 in `new'
replace p_logPop=`p_logPop'                 in `new'
replace b_vehicularity=`b_vehicularity'     in `new'
replace p_vehicularity=`p_vehicularity'     in `new'
replace NF=`n'                                in `new'
drop if depvar==""
save parametric, replace

*2. Mixed Regression with Feffects only with interaction
use if Num>=`n' & `Keyvariable'!=. using data, clear
gen logPop=log(Pop)
mixed `Keyvariable' c.logPop##vehicularity

mat D=r(table)

local N=e(N)
local b_logPop=D[1,1]
local p_logPop=D[4,1]
local b_vehicularity=D[1,3]
local p_vehicularity=D[4,3]
local b_interaction=D[1,5]
local p_interaction=D[4,5]

use parametric, clear
local new=_N+1
set obs `new'
replace depvar="`title'" in  `new'
replace Fixed_effects="log Population, vehicularity, interaction" in `new'
replace Random_intercepts="" in `new'
replace Random_slopes="" in `new'
replace N=`N' in `new'
replace b_logPop=`b_logPop'                 in `new'
replace p_logPop=`p_logPop'                 in `new'
replace b_vehicularity=`b_vehicularity'     in `new'
replace p_vehicularity=`p_vehicularity'     in `new'
replace b_interaction=`b_interaction'     in `new'
replace p_interaction=`p_interaction'     in `new'
replace NF=`n'                                in `new'
drop if depvar==""
save parametric, replace

*3. Mixed Regression with Feffects + Rintercepts for families without interaction
use if Num>=`n' & `Keyvariable'!=. using data, clear
gen logPop=log(Pop)
mixed `Keyvariable'  logPop vehicularity || Family:


mat D=r(table)

local N=e(N)
local b_logPop=D[1,1]
local p_logPop=D[4,1]
local b_vehicularity=D[1,2]
local p_vehicularity=D[4,2]


use parametric, clear
local new=_N+1
set obs `new'
replace depvar="`title'" in  `new'
replace Fixed_effects="log Population, vehicularity" in `new'
replace Random_intercepts="Language families" in `new'
replace Random_slopes="" in `new'
replace N=`N' in `new'
replace b_logPop=`b_logPop'                 in `new'
replace p_logPop=`p_logPop'                 in `new'
replace b_vehicularity=`b_vehicularity'     in `new'
replace p_vehicularity=`p_vehicularity'     in `new'
replace NF=`n'                                in `new'
drop if depvar==""
save parametric, replace

*4. Mixed Regression with Feffects + Rintercepts for families with interaction
use if Num>=`n' & `Keyvariable'!=. using data, clear
gen logPop=log(Pop)
mixed `Keyvariable' c.logPop##vehicularity || Family:

mat D=r(table)

local N=e(N)
local b_logPop=D[1,1]
local p_logPop=D[4,1]
local b_vehicularity=D[1,3]
local p_vehicularity=D[4,3]
local b_interaction=D[1,5]
local p_interaction=D[4,5]

use parametric, clear
local new=_N+1
set obs `new'
replace depvar="`title'" in  `new'
replace Fixed_effects="log Population, vehicularity, interaction" in `new'
replace Random_intercepts="Language families" in `new'
replace Random_slopes="" in `new'
replace N=`N' in `new'
replace b_logPop=`b_logPop'                 in `new'
replace p_logPop=`p_logPop'                 in `new'
replace b_vehicularity=`b_vehicularity'     in `new'
replace p_vehicularity=`p_vehicularity'     in `new'
replace b_interaction=`b_interaction'     in `new'
replace p_interaction=`p_interaction'     in `new'
replace NF=`n'                                in `new'
drop if depvar==""
save parametric, replace

*5. Mixed Regression with Feffects + Rintercept for families without interaction & at least 10 data points per family per i.V.
use if Num>=`n' & `Keyvariable'!=. using data, clear 
gen logPop=log(Pop)

bysort Family: gen howmany=_N
drop if howmany<20


mixed `Keyvariable' logPop vehicularity || Family: logPop 

mat D=r(table)

local N=e(N)
local b_logPop=D[1,1]
local p_logPop=D[4,1]
local b_vehicularity=D[1,2]
local p_vehicularity=D[4,2]


use parametric, clear
local new=_N+1
set obs `new'
replace depvar="`title'" in  `new'
replace Fixed_effects="log Population, vehicularity" in `new'
replace Random_intercepts="Language families" in `new'
replace Random_slopes="Language families" in `new'
replace N=`N' in `new'
replace b_logPop=`b_logPop'                 in `new'
replace p_logPop=`p_logPop'                 in `new'
replace b_vehicularity=`b_vehicularity'     in `new'
replace p_vehicularity=`p_vehicularity'     in `new'
replace NF=`n'                                in `new'
drop if depvar==""
save parametric, replace

*6. Mixed Regression with Feffects + Rintercept for families with interaction & at least 10 data points per family per i.V.
use if Num>=`n' & `Keyvariable'!=. using data, clear 
gen logPop=log(Pop)

bysort Family: gen howmany=_N
drop if howmany<30

gen interaction=logPop*vehicularity

mixed `Keyvariable' logPop vehicularity interaction || Family: logPop interaction 

mat D=r(table)

local N=e(N)
local b_logPop=D[1,1]
local p_logPop=D[4,1]
local b_vehicularity=D[1,2]
local p_vehicularity=D[4,2]
local b_interaction=D[1,3]
local p_interaction=D[4,3]

use parametric, clear
local new=_N+1
set obs `new'
replace depvar="`title'" in  `new'
replace Fixed_effects="log Population, vehicularity, interaction" in `new'
replace Random_intercepts="Language families" in `new'
replace Random_slopes="Language families" in `new'
replace N=`N' in `new'
replace b_logPop=`b_logPop'                 in `new'
replace p_logPop=`p_logPop'                 in `new'
replace b_vehicularity=`b_vehicularity'     in `new'
replace p_vehicularity=`p_vehicularity'     in `new'
replace b_interaction=`b_interaction'     in `new'
replace p_interaction=`p_interaction'     in `new'
replace NF=`n'                                in `new'
drop if depvar==""
save parametric, replace

*7. Mixed Regression with Feffects + Rintercepts for families & areas without interaction
use if Num>=`n' & `Keyvariable'!=. using data, clear
drop if Family==""|Area==""
gen logPop=log(Pop)
mixed `Keyvariable' logPop vehicularity || Family: || Area:

mat D=r(table)

local N=e(N)
local b_logPop=D[1,1]
local p_logPop=D[4,1]
local b_vehicularity=D[1,2]
local p_vehicularity=D[4,2]

use parametric, clear
local new=_N+1
set obs `new'
replace depvar="`title'" in  `new'
replace Fixed_effects="log Population, vehicularity" in `new'
replace Random_intercepts="Language families & areas" in `new'
replace Random_slopes="" in `new'
replace N=`N' in `new'
replace b_logPop=`b_logPop'                 in `new'
replace p_logPop=`p_logPop'                 in `new'
replace b_vehicularity=`b_vehicularity'     in `new'
replace p_vehicularity=`p_vehicularity'     in `new'
replace NF=`n'                                in `new'
drop if depvar==""
save parametric, replace


*8. Mixed Regression with Feffects + Rintercepts for families & areas with interaction
use if Num>=`n' & `Keyvariable'!=. using data, clear
drop if Family==""|Area==""
gen logPop=log(Pop)
mixed `Keyvariable' c.logPop##vehicularity || Family: || Area:

mat D=r(table)

local N=e(N)
local b_logPop=D[1,1]
local p_logPop=D[4,1]
local b_vehicularity=D[1,3]
local p_vehicularity=D[4,3]
local b_interaction=D[1,5]
local p_interaction=D[4,5]

use parametric, clear
local new=_N+1
set obs `new'
replace depvar="`title'" in  `new'
replace Fixed_effects="log Population, vehicularity, interaction" in `new'
replace Random_intercepts="Language families & areas" in `new'
replace Random_slopes="" in `new'
replace N=`N' in `new'
replace b_logPop=`b_logPop'                 in `new'
replace p_logPop=`p_logPop'                 in `new'
replace b_vehicularity=`b_vehicularity'     in `new'
replace p_vehicularity=`p_vehicularity'     in `new'
replace b_interaction=`b_interaction'     in `new'
replace p_interaction=`p_interaction'     in `new'
replace NF=`n'                                in `new'
drop if depvar==""
save parametric, replace
}
exit