
/*
Program to calculate and return r2 value
*/
capture program drop permcorr
program permcorr, rclass
version 14
args response fac_intrst
marksample touse
corr `response' `fac_intrst'
return scalar r2 = r(rho)^2
end

qui {
local depvar `1'
local reps `4'
local variation `5'

/* Model specification and titles */
if `2'==1 {
	local model `"no control"'
} 
if `2'==2 {
	local model `"logPop"'
} 

if `2'==3 {
	local model `"logPop || Family:"'
} 

if `2'==4 {
	local model `"logPop || Area:"' 
}

if `2'==5 {
	local model `"logPop || Family: || Area:"' 
}

if `2'==6 {
	local model `"logPop || Family: logPop"' 
}

if `2'==7 {
	local model `"logPop || Area: logPop"' 
}

*************************
use data, clear

/* For the L1plusL2 version: add estimated L2 number to population estimate */
if "`variation'"=="L1plusL2" {
		drop if L2prop==.
		replace Pop=Pop/(1-L2prop) if L2prop!=1
	}
	
/* For the vehicularity0 version: drop all non vehicular languages with L2prop>0 */
if "`variation'"=="vehicularity0" {
		drop if vehicularity==0 & L2prop>0
	}	
drop if `depvar'==.

if `2'==3|`2'==5|`2'==6 {
	drop if Family==""
}

if `2'==4|`2'==5|`2'==7 {
	drop if Area==""
}

if `3'==6 {
	keep if NumChap>=6
}

if `2'==6 {
	bysort Family: gen n=_N
	drop if n<10
}

if `2'==7 {
	bysort Area: gen n=_N
	drop if n<10
}

/* logged population size */
gen logPop=log(Pop)

if `2'!=1 {
	/* for all models except the model without control:
	run mixed model of depvar on control variables and obtain residuals
	*/
	mixed `depvar' `model'
	predict `depvar'_res, resid
	drop if `depvar'_res==.
	local depvar `depvar'_res
	}
	/* Permuation test */
	corr `depvar' vehicularity
	local r2=r(rho)^2
	local corr=r(rho)
	local N=r(N)
	permute `depvar' r2=r(r2), reps(`reps') nowarn: permcorr `depvar' vehicularity

	tempname temp1
	mat `temp1'=r(p)
	local p=`temp1'[1,1]

/* Store the results */
clear
set obs 1
gen depvar="`depvar'"
gen model="`model'"
gen reps=`reps'
gen r2=`r2'
gen corr=`corr'
gen p=`p'
gen N=`N'
gen NumChap=`3'
save permute_`2', replace


* generate finished file */
clear
set obs 1
gen v=1
save finished_`2', replace
clear
}         
exit, STATA 
