
/*
Program to calculate and return r2 value
*/
capture program drop permcorr
program permcorr, rclass
version 14
args response fac_intrst
marksample touse
corr `response' `fac_intrst'
return scalar r2 = r(rho)^2
end

qui {
local depvar `1'
local reps `4'

/* Model specification and titles */
if `2'==1 {
	local model `"no control"'
} 
if `2'==2 {
	local model `"logPop"'
} 

if `2'==3 {
	local model `"logPop || Family:"'
} 

if `2'==4 {
	local model `"logPop || Area:"' 
}

if `2'==5 {
	local model `"logPop || Family: || Area:"' 
}

if `2'==6 {
	local model `"logPop || Family: logPop"' 
}

if `2'==7 {
	local model `"logPop || Area: logPop"' 
}

*************************
use data, clear
drop if `depvar'==.

if `2'==3|`2'==5|`2'==6 {
	drop if Family==""
}

if `2'==4|`2'==5|`2'==7 {
	drop if Area==""
}

if `3'==6 {
	keep if NumChap>=6
}

if `2'==6 {
	bysort Family: gen n=_N
	drop if n<10
}

if `2'==7 {
	bysort Area: gen n=_N
	drop if n<10
}

/* logged population size */
gen logPop=log(Pop)


/* 
Generate a new variable that has a comparable correlation with `depvar' as logPop, but is not correlated with logPop 
Solution by Clyde Schechter: https://www.statalist.org/forums/forum/general-stata-discussion/general/565527-creating-a-variable-with-a-known-correlation-with-existing-variables 
*/

sum `depvar'
gen double z_`depvar'=(`depvar'-r(mean))/r(sd)
sum logPop
gen double z_logPop=(logPop-r(mean))/r(sd)
corr z_`depvar' z_logPop
scalar r12=r(rho)
scalar r1=r12
scalar r2=0

scalar a2=(r1*r12-r2)/(r12^2-1)
scalar a1=r1-r12*a2

scalar a3 = sqrt(1-a1^2-a2^2 -2 * a1 * a2 * r12)

set seed 30818103
gen double e = rnormal()

gen y = a1*z_`depvar'+a2*z_logPop + a3*e

*use y as new logPop variable to validate the approach

replace logPop=y

if `2'!=1 {
	/* for all models except the model without control:
	run mixed model of depvar on control variables and obtain residuals
	*/
	mixed `depvar' `model'
	predict `depvar'_res, resid
	drop if `depvar'_res==.
	local depvar `depvar'_res
	}
	/* Permuation test */
	corr `depvar' vehicularity
	local r2=r(rho)^2
	local corr=r(rho)
	local N=r(N)
	permute `depvar' r2=r(r2), reps(`reps') nowarn: permcorr `depvar' vehicularity

	tempname temp1
	mat `temp1'=r(p)
	local p=`temp1'[1,1]

/* Store the results */
clear
set obs 1
gen depvar="`depvar'"
gen model="`model'"
gen reps=`reps'
gen r2=`r2'
gen corr=`corr'
gen p=`p'
gen N=`N'
gen NumChap=`3'
save permute_`2', replace


* generate finished file */
clear
set obs 1
gen v=1
save finished_`2', replace
clear
}         
exit, STATA 
